<?php

/**
 * The admin-specific functionality for the Model settings page.
 *
 * This class manages the admin menu, settings registration, and rendering for the Model configuration page.
 * It allows users to configure and save their own LLM provider settings (such as OpenAI or CustomGPT.ai).
 *
 * @package    ai-tool-center
 * @subpackage Aitoce/admin/model-page
 * @author     sjvision <contact@ai-tool-center.com>
 */

class Aitoce_Admin_Model_Page
{
    /**
     * Handles admin notifications.
     * @var Aitoce_Admin_Notifications
     */
    private $notify;

    /**
     * Handles options and field rendering.
     * @var Aitoce_Admin_Options
     */
    private $options;

    /**
     * Constructor.
     * Initializes notification and options handler objects.
     */
    public function __construct()
    {
        $this->notify = new Aitoce_Admin_Notifications();
        $this->options = new Aitoce_Admin_Options();
    }

    /**
     * Adds the Model submenu page to the WordPress admin menu.
     */
    public function aitoce_add_model_menu(): void
    {
        add_submenu_page(
            parent_slug: AITOCE_MENU_SLUG,
            page_title: __('Model', 'ai-tool-center'),
            menu_title: __('Model', 'ai-tool-center'),
            capability: 'manage_options',
            menu_slug: AITOCE_MENU_SLUG_MODEL,
            callback: [$this, 'aitoce_render_model_page']
        );
    }

    /**
     * Renders the Model admin page.
     * Displays admin errors and includes the settings page template.
     */
    public function aitoce_render_model_page(): void
    {
        $this->notify->aitoce_display_admin_errors();
        include plugin_dir_path(__FILE__) . 'partials/aitoce-admin-model-display.php';
    }

    /**
     * Registers settings, sections, and fields for the Model settings page.
     * Adds fields for using a OpenAI API Models, Model Name, and API key selection.
     * Adds fields for using a Custom API Model, URL, API key, and Model Name selection.
     */
    public function aitoce_register_model_settings(): void
    {
        // Register the OpenAI settings group and sanitize callback for OpenAI API
        register_setting(
            AITOCE_OPTION_SLUG_MODEL_OPENAI,
            AITOCE_OPTION_NAME_MODEL_OPENAI,
            ['sanitize_callback' => [$this, 'aitoce_sanitize_openai_settings']]
        );

        // Add the main OpenAI settings section
        add_settings_section(
            AITOCE_OPTION_SECTION_MODEL_OPENAI,
            __('OpenAI Models', 'ai-tool-center'),
            '__return_false',
            AITOCE_OPTION_SLUG_MODEL_OPENAI
        );

        // Dropdown select for choosing the OpenAI model
        foreach(AITOCE_OPENAI_MODELS as $model => $values){
            $open_ai_models[esc_html($model)] = esc_html($values['name']);
        }
        $this->options->aitoce_add_select_field(
            'openai_model',
            __('Model', 'ai-tool-center'),
            $open_ai_models,
            esc_attr(AITOCE_OPTION_NAME_MODEL_OPENAI),
            esc_attr(AITOCE_OPTION_SLUG_MODEL_OPENAI),
            esc_attr(AITOCE_OPTION_SECTION_MODEL_OPENAI),
            'Select an OpenAI Model',
        );

        // Text field for the custom OpenAI API key
        $this->options->aitoce_add_text_field(
            'openai_api_key',
            __('API Key', 'ai-tool-center'),
            __('API Key', 'ai-tool-center'),
            esc_attr(AITOCE_OPTION_NAME_MODEL_OPENAI),
            esc_attr(AITOCE_OPTION_SLUG_MODEL_OPENAI),
            esc_attr(AITOCE_OPTION_SECTION_MODEL_OPENAI),
            'Enter your OpenAI API key.'
        );





        // Register the settings group and sanitize callback for Custom API
        register_setting(
            AITOCE_OPTION_SLUG_MODEL_CUSTOM,
            AITOCE_OPTION_NAME_MODEL_CUSTOM,
            ['sanitize_callback' => [$this, 'aitoce_sanitize_custom_settings']]
        );

        // Add the main settings section
        add_settings_section(
            AITOCE_OPTION_SECTION_MODEL_CUSTOM,
            __('Custom API Model', 'ai-tool-center'),
            [$this, 'aitoce_model_custom_section_callback'],// '__return_false',
            AITOCE_OPTION_SLUG_MODEL_CUSTOM
        );

        // Checkbox to enable using a custom LLM provider
        $this->options->aitoce_add_checkbox_field(
            'custom_llm',
            __('Custom API Model', 'ai-tool-center'),
            esc_attr(AITOCE_OPTION_NAME_MODEL_CUSTOM),
            esc_attr(AITOCE_OPTION_SLUG_MODEL_CUSTOM),
            esc_attr(AITOCE_OPTION_SECTION_MODEL_CUSTOM),
            'Check this if you want to use a Custom API Model.'
        );

        // Text field for the custom LLM base URL
        $this->options->aitoce_add_text_field(
            'custom_api_url',
            __('API URL', 'ai-tool-center'),
            esc_url('https://api.openai.com/v1/responses'),
            esc_attr(AITOCE_OPTION_NAME_MODEL_CUSTOM),
            esc_attr(AITOCE_OPTION_SLUG_MODEL_CUSTOM),
            esc_attr(AITOCE_OPTION_SECTION_MODEL_CUSTOM),
            'Enter your Custom Model API URL.'
        );

        // Text field for the custom LLM API key
        $this->options->aitoce_add_text_field(
            'custom_api_key',
            __('API Key', 'ai-tool-center'),
            __('API Key', 'ai-tool-center'),
            esc_attr(AITOCE_OPTION_NAME_MODEL_CUSTOM),
            esc_attr(AITOCE_OPTION_SLUG_MODEL_CUSTOM),
            esc_attr(AITOCE_OPTION_SECTION_MODEL_CUSTOM),
            'Enter your Custom Model API key.'
        );

        // Text field for the custom LLM API key
        $this->options->aitoce_add_text_field(
            'custom_model',
            __('Model', 'ai-tool-center'),
            __('Model', 'ai-tool-center'),
            esc_attr(AITOCE_OPTION_NAME_MODEL_CUSTOM),
            esc_attr(AITOCE_OPTION_SLUG_MODEL_CUSTOM),
            esc_attr(AITOCE_OPTION_SECTION_MODEL_CUSTOM),
            'Enter your Custom Model Name.'
        );
    }

    /**
     * Sanitizes the settings input for the Model options.
     *
     * @param array $input The input array from the settings form.
     * @return array Sanitized settings.
     */
    public function aitoce_sanitize_openai_settings(array $input): array
    {
        return [
            'openai_model' => sanitize_text_field($input['openai_model'] ?? ''),
            'openai_api_key' => sanitize_text_field($input['openai_api_key'] ?? ''),
        ];
    }
    public function aitoce_sanitize_custom_settings(array $input): array
    {
        return [
            'custom_llm' => isset($input['custom_llm']) ? 1 : 0,
            'custom_api_url' => sanitize_text_field($input['custom_api_url'] ?? ''),
            'custom_api_key' => sanitize_text_field($input['custom_api_key'] ?? ''),
            'custom_model' => sanitize_text_field($input['custom_model'] ?? ''),
        ];
    }

    /**
     * Outputs a description for the NimBot Page settings section.
     * Shows the shortcode needed to activate the assistant on a page.
     */
    public function aitoce_model_custom_section_callback()
    {
        echo '
        <table class="form-table" role="presentation">
            <tbody>
                <tr>
                    <td><p>If you <strong>Check</strong> the box to use <strong>Custom API Model</strong>, these <strong>values</strong> will <span class="aitoce-red"><strong>override</strong></span> the <strong>OpenAI Models</strong> for <strong>Basic</strong> and <strong>Advanced</strong> accounts.</p></td>
                </tr>
            </tbody>
        </table>';
    }

}
