<?php

/**
 * The admin-specific notification functionality of the plugin.
 *
 * This class handles displaying admin error and notification messages
 * in the WordPress dashboard for the AI Tool Center plugin.
 *
 * @package    ai-tool-center
 * @subpackage Aitoce/admin/notifications
 * @author     sjvision <contact@ai-tool-center.com>
 */
class Aitoce_Admin_Notifications
{
    /**
     * Display relevant admin error messages based on account and model settings.
     *
     * Checks the user's account status and LLM settings, and displays
     * error notifications if there are issues with the account or configuration.
     */
    public function aitoce_display_admin_errors()
    {
        $api_call = new Aitoce_Api;
        $account_membership = $api_call->aitoce_get_account();

        $options = new Aitoce_Admin_Options();
        $openai_model = $options->aitoce_get_option(AITOCE_OPTION_NAME_MODEL_OPENAI);
        $custom_model = $options->aitoce_get_option(AITOCE_OPTION_NAME_MODEL_CUSTOM);

        // Check if the account is valid.
        if (
            !in_array($account_membership['label'], AITOCE_ACCOUNT_LEVELS, true)
        ) {
            $this->aitoce_display_notification_message(
                'It looks like your <strong>Account Membership</strong> or <strong>API Key</strong> is missing or invalid. Head over to <a href="https://ai-tool-center.com" target="_blank">ai-tool-center.com</a> to check your account details and get your API key.',
                'error'
            );
        }

        // If Free account check OpenAI API key is present.
        if (
            $account_membership['label'] === AITOCE_ACCOUNT_LEVELS[0] &&
            (!isset($openai_model['openai_api_key']) || empty($openai_model['openai_api_key']))
        ) {
            $this->aitoce_display_notification_message(
                'With a <strong>Free</strong> account, you\'ll need to provide your own <strong>OpenAI API Key</strong> to enable the AI features of AI Tool Center and use the NimBot Assistant. Please complete the configuration under the <strong>OpenAI</strong> tab in the <strong>Model</strong> settings page.',
                'error'
            );
        }

        // If Basic account check if Custom API Model is selected
        if ($account_membership['label'] === AITOCE_ACCOUNT_LEVELS[1]) {
            if (
                (!isset($openai_model['openai_api_key']) || empty($openai_model['openai_api_key'])) &&
                (!isset($custom_model['custom_llm']) || $custom_model['custom_llm'] !== 1)
            ) {
                $this->aitoce_display_notification_message(
                    'With a <strong>Basic</strong> account, you\'ll need to provide your own <strong>OpenAI API Key</strong> or a <strong>Custom API Model</strong> to enable the AI features of AI Tool Center and use the NimBot Assistant. Please complete the configuration under the <strong>OpenAI</strong> tab or under the <strong>Custom</strong> tab in the <strong>Model</strong> settings page.',
                    'error'
                );
            }
        }

        // Check if Custom API Model is ticked
        if (isset($custom_model['custom_llm']) && $custom_model['custom_llm'] === 1) {
            // Check if Free account.
            if ($account_membership['label'] === AITOCE_ACCOUNT_LEVELS[0]) {
                $this->aitoce_display_notification_message(
                    'You\'ve selected a <strong>Custom API Model</strong>, but this feature is only available with a <strong>Basic</strong> or <strong>Advanced</strong> account. To activate <strong>Custom API Model</strong>, please upgrade at <a href="https://ai-tool-center.com" target="_blank">ai-tool-center.com</a>.',
                    'error'
                );
            } elseif (
                empty($custom_model['custom_api_url']) ||
                empty($custom_model['custom_api_key']) ||
                empty($custom_model['custom_model'])
            ) {
                $this->aitoce_display_notification_message(
                    'You\'ve selected a <strong>Custom API Model</strong>, but some required settings are missing. Please complete the configuration under the <strong>Custom</strong> tab in the <strong>Model</strong> settings page.',
                    'error'
                );
            }
        }
    }

    /**
     * Display a notification message in the WordPress admin.
     *
     * @param string $message   The message to display.
     * @param string $error_type The type of notice: 'success', 'error', etc.
     * @param string $code      Optional error code to display.
     */
    public function aitoce_display_notification_message($message, $error_type = 'success', $code = '')
    {
        if (!empty($code))
            $code = ' Error code #' . esc_html($code);

        printf(
            '<div class="notice notice-%s is-dismissible"><p>%s%s</p></div>',
            esc_attr($error_type),
            wp_kses_post($message),
            esc_html($code)
        );
    }
}