<?php

/**
 * The admin-specific functionality for the NimBot Page settings page.
 *
 * This class manages the admin menu, settings registration, and rendering for the NimBot Page chatbot.
 *
 * @package    ai-tool-center
 * @subpackage Aitoce/admin/page-page
 * @author     sjvision <contact@ai-tool-center.com>
 */
class Aitoce_Admin_Page_Page
{
    /**
     * Handles admin notifications.
     * @var Aitoce_Admin_Notifications
     */
    private $notify;

    /**
     * Handles options and field rendering.
     * @var Aitoce_Admin_Options
     */
    private $options;

    /**
     * Constructor.
     * Initializes notification and options handler objects.
     */
    public function __construct()
    {
        $this->notify = new Aitoce_Admin_Notifications();
        $this->options = new Aitoce_Admin_Options();
    }

    /**
     * Adds the NimBot Page submenu page to the WordPress admin menu.
     */
    public function aitoce_add_page_menu(): void
    {
        add_submenu_page(
            parent_slug: AITOCE_MENU_SLUG,
            page_title: __('NimBot Page', 'ai-tool-center'),
            menu_title: __('NimBot Page', 'ai-tool-center'),
            capability: 'manage_options',
            menu_slug: AITOCE_MENU_SLUG_PAGE,
            callback: [$this, 'aitoce_render_page_page']
        );
    }

    /**
     * Renders the NimBot Page admin page.
     * Displays admin errors and includes the settings page template.
     */
    public function aitoce_render_page_page(): void
    {
        $this->notify->aitoce_display_admin_errors();
        include plugin_dir_path(__FILE__) . 'partials/aitoce-admin-page-display.php';
    }

    /**
     * Registers settings, sections, and fields for the NimBot Page settings page.
     * Adds fields for role, memory retention, and inclusion rules.
     */
    public function aitoce_register_page_settings(): void
    {
        $api_call = new Aitoce_Api;
        $raw_account_level = $api_call->aitoce_get_account();

        $account_membership = [
            'label'    => in_array($raw_account_level['label'], AITOCE_ACCOUNT_LEVELS) ? sanitize_text_field($raw_account_level['label']) : 'Free',
            'level'    => isset($raw_account_level['level']) ? intval($raw_account_level['level']) : 0,
            'status'    => isset($raw_account_level['status']) ? intval($raw_account_level['status']) : 0,
        ];

        // Register the settings group and sanitize callback
        register_setting(
            AITOCE_OPTION_SLUG_PAGE,
            AITOCE_OPTION_NAME_PAGE,
            ['sanitize_callback' => [$this, 'aitoce_sanitize_settings']]
        );

        // Add the main settings section
        add_settings_section(
            AITOCE_OPTION_SECTION_PAGE,
            __('NimBot Page', 'ai-tool-center'),
            [$this, 'aitoce_page_section_callback'],
            AITOCE_OPTION_SLUG_PAGE
        );

        // Textarea for defining the assistant's role/personality
        $this->options->aitoce_add_textarea_field(
            'role',
            __('Role', 'ai-tool-center'),
            4,
            esc_attr(AITOCE_OPTION_NAME_PAGE),
            esc_attr(AITOCE_OPTION_SLUG_PAGE),
            esc_attr(AITOCE_OPTION_SECTION_PAGE),
            'Enter how you want NimBot Page Assistant to act.'
        );

        // Select field for memory retention (number of messages remembered)
        $history_max = AITOCE_NIMBOT_DEFAULTS[$account_membership['label']]['page']['history'];
        for ($i = 1; $i <= $history_max; $i++) {
            $history_data[$i] = $i;
        }
        $this->options->aitoce_add_select_field(
            'history',
            __('Memory Retention', 'ai-tool-center'),
            $history_data,
            esc_attr(AITOCE_OPTION_NAME_PAGE),
            esc_attr(AITOCE_OPTION_SLUG_PAGE),
            esc_attr(AITOCE_OPTION_SECTION_PAGE),
            'The higher the retention the higher the token costs when using your own API end-points.'
        );

        // Textarea for specifying which pages to include the assistant on
        $this->options->aitoce_add_textarea_field(
            'incl_pages',
            __('Inclusion by Page', 'ai-tool-center'),
            4,
            esc_attr(AITOCE_OPTION_NAME_PAGE),
            esc_attr(AITOCE_OPTION_SLUG_PAGE),
            esc_attr(AITOCE_OPTION_SECTION_PAGE),
            'With a <strong>Free</strong> account only the first <strong>3 Page</strong> slugs will be included.<br />Add <strong>Page</strong> slugs and separate each <strong>Page</strong> with a comma. i.e page-1, page-2, page/sub-page-3'
        );

        // Textarea for specifying which categories to include the assistant on
        $this->options->aitoce_add_textarea_field(
            'incl_posts',
            __('Inclusion by Post', 'ai-tool-center'),
            4,
            esc_attr(AITOCE_OPTION_NAME_PAGE),
            esc_attr(AITOCE_OPTION_SLUG_PAGE),
            esc_attr(AITOCE_OPTION_SECTION_PAGE),
            'Not available for <strong>Free</strong> accounts.<br />Post Category <strong>"NimBot PopUp"</strong> will be added automatically for <strong>Basic and Advanced</strong> accounts.<br />You can add additional <strong>Post</strong> slugs and separate each <strong>Post</strong> with a comma. i.e post-1, post-2, post/sub-post-3'
        );

        // Hidden field for transcript retention (not user-editable here)
        $this->options->aitoce_add_hidden_field(
            'transcript',
            esc_attr(AITOCE_NIMBOT_DEFAULTS[$account_membership['label']]['page']['transcript']),
            esc_attr(AITOCE_OPTION_NAME_PAGE),
            esc_attr(AITOCE_OPTION_SLUG_PAGE),
            esc_attr(AITOCE_OPTION_SECTION_PAGE)
        );
    }

    /**
     * Sanitizes the settings input for the NimBot Page options.
     *
     * @param array $input The input array from the settings form.
     * @return array Sanitized settings.
     */
    public function aitoce_sanitize_settings(array $input): array
    {
        return [
            'role' => sanitize_textarea_field($input['role'] ?? ''),
            'history' => sanitize_text_field($input['history'] ?? ''),
            'transcript' => sanitize_text_field($input['transcript'] ?? ''),
            'incl_pages' => sanitize_textarea_field($input['incl_pages'] ?? ''),
            'incl_posts' => sanitize_textarea_field($input['incl_posts'] ?? ''),
        ];
    }

    /**
     * Outputs a description for the NimBot Page settings section.
     * Shows the shortcode needed to activate the assistant on a page.
     */
    public function aitoce_page_section_callback()
    {
        printf(
            '
        <table class="form-table" role="presentation">
            <tbody>
                <tr><td><p>%s</p><h3>&nbsp;&nbsp;%s</h3></td></tr></tbody></table>',
            esc_html__('To activate Nimbot Page Assistant on any public-facing page of the website by adding this shortcode:', 'ai-tool-center'),
            esc_html('[nimbot-assistant]')
        );
    }

}
