<?php

/**
 * The admin-specific functionality for the NimBot PopUp settings page.
 *
 * This class manages the admin menu, settings registration, and rendering for the NimBot PopUp chatbot.
 *
 * @package    ai-tool-center
 * @subpackage Aitoce/admin/popup-page
 * @author     sjvision <contact@ai-tool-center.com>
 */
class Aitoce_Admin_Popup_Page
{
    /**
     * Handles admin notifications.
     * @var Aitoce_Admin_Notifications
     */
    private $notify;

    /**
     * Handles options and field rendering.
     * @var Aitoce_Admin_Options
     */
    private $options;

    /**
     * Constructor.
     * Initializes notification and options handler objects.
     */
    public function __construct()
    {
        $this->notify = new Aitoce_Admin_Notifications();
        $this->options = new Aitoce_Admin_Options();
    }

    /**
     * Adds the NimBot PopUp submenu page to the WordPress admin menu.
     */
    public function aitoce_add_popup_menu(): void
    {
        add_submenu_page(
            parent_slug: AITOCE_MENU_SLUG,
            page_title: __('NimBot PopUp', 'ai-tool-center'),
            menu_title: __('NimBot PopUp', 'ai-tool-center'),
            capability: 'manage_options',
            menu_slug: AITOCE_MENU_SLUG_POPUP,
            callback: [$this, 'aitoce_render_popup_page']
        );
    }

    /**
     * Renders the NimBot PopUp admin page.
     * Displays admin errors and includes the settings page template.
     */
    public function aitoce_render_popup_page(): void
    {
        $this->notify->aitoce_display_admin_errors();
        include plugin_dir_path(__FILE__) . 'partials/aitoce-admin-popup-display.php';
    }

    /**
     * Registers settings, sections, and fields for the NimBot PopUp settings page.
     * Adds fields for activation, role, memory retention, transcript retention, and inclusion rules.
     */
    public function aitoce_register_popup_settings(): void
    {
        $api_call = new Aitoce_Api;
        $raw_account_level = $api_call->aitoce_get_account();

        $account_membership = [
            'label'    => in_array($raw_account_level['label'], AITOCE_ACCOUNT_LEVELS) ? sanitize_text_field($raw_account_level['label']) : 'Free',
            'level'    => isset($raw_account_level['level']) ? intval($raw_account_level['level']) : 0,
            'status'    => isset($raw_account_level['status']) ? intval($raw_account_level['status']) : 0,
        ];

        // Register the settings group and sanitize callback
        register_setting(
            AITOCE_OPTION_SLUG_POPUP,
            AITOCE_OPTION_NAME_POPUP,
            ['sanitize_callback' => [$this, 'aitoce_sanitize_settings']]
        );

        // Add the main settings section
        add_settings_section(
            AITOCE_OPTION_SECTION_POPUP,
            __('NimBot PopUp', 'ai-tool-center'),
            '__return_false',
            AITOCE_OPTION_SLUG_POPUP
        );

        // Checkbox to activate the popup chatbot
        $this->options->aitoce_add_checkbox_field(
            'popup_activate',
            __('Activate NimBot PopUp', 'ai-tool-center'),
            esc_attr(AITOCE_OPTION_NAME_POPUP),
            esc_attr(AITOCE_OPTION_SLUG_POPUP),
            esc_attr(AITOCE_OPTION_SECTION_POPUP),
            'Check this if you want to activate NimBot PopUp Chatbot on the front-end.'
        );

        // Textarea for defining the assistant's role/personality
        $this->options->aitoce_add_textarea_field(
            'role',
            __('Role', 'ai-tool-center'),
            4,
            esc_attr(AITOCE_OPTION_NAME_POPUP),
            esc_attr(AITOCE_OPTION_SLUG_POPUP),
            esc_attr(AITOCE_OPTION_SECTION_POPUP),
            'Enter how you want NimBot PopUp Assistant to act.<br />i.e "You are a helpful assistant."'
        );

        // Select field for memory retention (number of messages remembered)
        $history_max = AITOCE_NIMBOT_DEFAULTS[$account_membership['label']]['popup']['history'];
        for ($i = 1; $i <= $history_max; $i++) {
            $history_data[$i] = $i;
        }
        $this->options->aitoce_add_select_field(
            'history',
            __('Memory Retention', 'ai-tool-center'),
            $history_data,
            esc_attr(AITOCE_OPTION_NAME_POPUP),
            esc_attr(AITOCE_OPTION_SLUG_POPUP),
            esc_attr(AITOCE_OPTION_SECTION_POPUP),
            'The higher the retention the higher the token costs when using your own API end-points.'
        );

        // Select field for transcript retention (how long to keep transcripts)
        $transcript_max = AITOCE_NIMBOT_DEFAULTS[$account_membership['label']]['popup']['transcript'];
        for ($i = 12; $i <= $transcript_max; $i += 12) {
            $transcript_data[$i] = $i;
        }
        $this->options->aitoce_add_select_field(
            'transcript',
            __('Transcript Retention', 'ai-tool-center'),
            $transcript_data,
            esc_attr(AITOCE_OPTION_NAME_POPUP),
            esc_attr(AITOCE_OPTION_SLUG_POPUP),
            esc_attr(AITOCE_OPTION_SECTION_POPUP),
            'How many <strong>hours</strong> to save message transcripts for. So they can be reviewed later.'
        );

        // Textarea for specifying which pages to include the popup on
        $this->options->aitoce_add_textarea_field(
            'incl_pages',
            __('Inclusion by Page', 'ai-tool-center'),
            4,
            esc_attr(AITOCE_OPTION_NAME_POPUP),
            esc_attr(AITOCE_OPTION_SLUG_POPUP),
            esc_attr(AITOCE_OPTION_SECTION_POPUP),
            'With a <strong>Free</strong> account only the first 3 <strong>Page</strong> slugs will be included.<br />Add <strong>Page</strong> slugs and separate each <strong>Page</strong> with a comma. i.e page-1, page-2, page/sub-page-3'
        );

        // Textarea for specifying which categories to include the popup on
        $this->options->aitoce_add_textarea_field(
            'incl_posts',
            __('Inclusion by Post', 'ai-tool-center'),
            4,
            esc_attr(AITOCE_OPTION_NAME_POPUP),
            esc_attr(AITOCE_OPTION_SLUG_POPUP),
            esc_attr(AITOCE_OPTION_SECTION_POPUP),
            'Not available for <strong>Free</strong> accounts.<br />Post Category <strong>"NimBot PopUp"</strong> will be added automatically for <strong>Basic and Advanced</strong> accounts.<br />You can add additional <strong>Post</strong> slugs and separate each <strong>Post</strong> with a comma. i.e post-1, post-2, post/sub-post-3'
        );
    }

    /**
     * Sanitizes the settings input for the NimBot PopUp options.
     *
     * @param array $input The input array from the settings form.
     * @return array Sanitized settings.
     */
    public function aitoce_sanitize_settings(array $input): array
    {
        return [
            'popup_activate' => isset($input['popup_activate']) ? 1 : 0,
            'role' => sanitize_textarea_field($input['role'] ?? ''),
            'history' => sanitize_text_field($input['history'] ?? ''),
            'transcript' => sanitize_text_field($input['transcript'] ?? ''),
            'incl_pages' => sanitize_textarea_field($input['incl_pages'] ?? ''),
            'incl_posts' => sanitize_textarea_field($input['incl_posts'] ?? ''),
        ];
    }

}
