<?php

/**
 * The admin-specific functionality for the Settings settings page.
 *
 * This class manages the admin menu, settings registration, and rendering for the Settings configuration page.
 * It allows users to configure and save their own LLM provider settings (such as OpenAI or CustomGPT.ai).
 *
 * @package    ai-tool-center
 * @subpackage Aitoce/admin/settings-page
 * @author     sjvision <contact@ai-tool-center.com>
 */

class Aitoce_Admin_Settings_Page
{
    /**
     * Handles admin notifications.
     * @var Aitoce_Admin_Notifications
     */
    private $notify;

    /**
     * Handles options and field rendering.
     * @var Aitoce_Admin_Options
     */
    private $options;

    /**
     * Constructor.
     * Initializes notification and options handler objects.
     */
    public function __construct()
    {
        $this->notify = new Aitoce_Admin_Notifications();
        $this->options = new Aitoce_Admin_Options();
    }

    /**
     * Adds the Settings submenu page to the WordPress admin menu.
     */
    public function aitoce_add_settings_menu(): void
    {
        add_submenu_page(
            parent_slug: AITOCE_MENU_SLUG,
            page_title: __('Settings', 'ai-tool-center'),
            menu_title: __('Settings', 'ai-tool-center'),
            capability: 'manage_options',
            menu_slug: AITOCE_MENU_SLUG_SETTINGS,
            callback: [$this, 'aitoce_render_settings_page']
        );
    }

    /**
     * Renders the Settings admin page.
     * Displays admin errors and includes the settings page template.
     */
    public function aitoce_render_settings_page(): void
    {
        $this->notify->aitoce_display_admin_errors();
        include plugin_dir_path(__FILE__) . 'partials/aitoce-admin-settings-display.php';
    }

    /**
     * Registers settings, sections, and fields for the Settings settings page.
     * Adds fields for using a custom LLM provider, base URL, API key, and settings selection.
     */
    public function aitoce_register_settings_settings(): void
    {
        // Register the settings group and sanitize callback
        register_setting(
            AITOCE_OPTION_SLUG_SETTINGS,
            AITOCE_OPTION_NAME_SETTINGS,
            ['sanitize_callback' => [$this, 'aitoce_sanitize_settings']]
        );

        // Add the main settings section
        add_settings_section(
            AITOCE_OPTION_SECTION_SETTINGS,
            __('Settings', 'ai-tool-center'),
            '__return_false',
            AITOCE_OPTION_SLUG_SETTINGS
        );

        // Checkbox to enable using a custom LLM provider
        $this->options->aitoce_add_checkbox_field(
            'delete_options',
            __('Delete On Deactivation', 'ai-tool-center'),
            esc_attr(AITOCE_OPTION_NAME_SETTINGS),
            esc_attr(AITOCE_OPTION_SLUG_SETTINGS),
            esc_attr(AITOCE_OPTION_SECTION_SETTINGS),
            'Check this if you want to <span class="aitoce-red"><strong>DELETE</strong></span> all <span class="aitoce-red"><strong>SETTINGS/OPTIONS</strong></span> and <span class="aitoce-red"><strong>VALUES</strong></span> on plugin <span class="aitoce-red"><strong>DEACTIVATION</strong></span>.<br /><span class="aitoce-red"><strong>This will include Account Settings, Model settings etc.</strong></span>'
        );
    }

    /**
     * Sanitizes the settings input for the Settings options.
     *
     * @param array $input The input array from the settings form.
     * @return array Sanitized settings.
     */
    public function aitoce_sanitize_settings($input): array
    {
        return [
            'delete_options' => isset($input['delete_options']) ? 1 : 0,
        ];
    }

}
