<?php

/**
 * The ajax requests functionality of the plugin.
 *
 * Handles AJAX requests for the Nimbot assistant, including retrieving user inputs,
 * sanitizing data, and sending API requests to the backend.
 *
 * @package    ai-tool-center
 * @subpackage Aitoce/includes
 * @author     sjvision <contact@ai-tool-center.com>
 */
class Aitoce_Ajax
{

    private $api_call;
    private $options;

    /**
     * Constructor.
     * Initializes API and options handler objects.
     */
    public function __construct()
    {
        $this->api_call = new Aitoce_Api();
        $this->options = new Aitoce_Admin_Options();
    }

    /**
     * Handles the main AJAX request for the Nimbot assistant.
     *
     * - Checks the AJAX nonce for security.
     * - Validates and sanitizes required input fields.
     * - Retrieves plugin settings for popup, page, and model.
     * - Builds the message body for the API request.
     * - If using a custom LLM, adds those settings to the request.
     * - Sends the request to the backend API and returns the response as JSON.
     */
    public function aitoce_nimbot_ajax_request()
    {
        check_ajax_referer('aitoce_ajax_nonce', 'aitoce_security');

        $api_call = new Aitoce_Api;
        $account_membership = $api_call->aitoce_get_account();

        // Define required fields and their error codes
        $required_fields = [
            'aitoce_message_id' => '0x80001001',
            'aitoce_last_prompt' => '0x80001002',
            'aitoce_prompt_format' => '0x80001003',
        ];

        // Validate and sanitize required fields
        $inputs = [];
        foreach ($required_fields as $field => $code) {
            if (empty($_REQUEST[$field])) {
                $this->aitoce_send_error_message("Missing field: $field", $code);
            }
            $inputs[$field] = sanitize_text_field(wp_unslash($_REQUEST[$field]));
        }

        $body_settings['popup'] = $this->options->aitoce_get_option(AITOCE_OPTION_NAME_POPUP);
        $body_settings['popup']['role'] = (!empty($body_settings['popup']['role']))? $body_settings['popup']['role']:'You are a helpful assistant.';
        
        $body_settings['page'] = $this->options->aitoce_get_option(AITOCE_OPTION_NAME_PAGE);
        $body_settings['page']['role'] = (!empty($body_settings['page']['role']))? $body_settings['page']['role']:'You are a helpful assistant.';

        // Build the message body for the API request
        $message_body = [
            'message' => [
                'assistant_role' => [
                    'role' => 'system',
                    'content' => esc_attr($body_settings[$inputs['aitoce_prompt_format']]['role']),
                ],
                'message' => [
                    'role' => 'user',
                    'content' => $inputs['aitoce_last_prompt'],
                ],
                'temperature' => 0.8,
                'message_id' => esc_attr($inputs['aitoce_message_id']),
                'history_count' => esc_attr($body_settings[$inputs['aitoce_prompt_format']]['history']),
                'transcript_count' => esc_attr($body_settings[$inputs['aitoce_prompt_format']]['transcript']),
                'page_inclusion' => esc_attr($body_settings[$inputs['aitoce_prompt_format']]['incl_pages']),
                'post_inclusion' => esc_attr($body_settings[$inputs['aitoce_prompt_format']]['incl_posts']),
            ]
        ];

        // Retrieve plugin settings for popup, page, and model
        $openai_model = $this->options->aitoce_get_option(AITOCE_OPTION_NAME_MODEL_OPENAI);
        $custom_model = $this->options->aitoce_get_option(AITOCE_OPTION_NAME_MODEL_CUSTOM);

        // Free account Model.
        if($account_membership['label'] === AITOCE_ACCOUNT_LEVELS[0])
        {
            $message_body['own_llm'] = [
                'aitoce_own_llm' => 1,
                'aitoce_own_api_url' => AITOCE_OPENAI_MODELS[$openai_model['openai_model']]['url'],
                'aitoce_own_api_key' => $openai_model['openai_api_key'],
                'aitoce_own_model' => $openai_model['openai_model'],
            ];
        }
        elseif($account_membership['label'] === AITOCE_ACCOUNT_LEVELS[1])
        {
            if($custom_model['custom_llm'] === 1)
            {
                $message_body['own_llm'] = [
                    'aitoce_own_llm' => 1,
                    'aitoce_own_api_url' => $custom_model['custom_api_url'],
                    'aitoce_own_api_key' => $custom_model['custom_api_key'],
                    'aitoce_own_model' => $custom_model['custom_model'],
                ];
            }else{
                $message_body['own_llm'] = [
                    'aitoce_own_llm' => 1,
                    'aitoce_own_api_url' => AITOCE_OPENAI_MODELS[$openai_model['openai_model']]['url'],
                    'aitoce_own_api_key' => $openai_model['openai_api_key'],
                    'aitoce_own_model' => $openai_model['openai_model'],
                ];
            }
        }
        elseif($account_membership['label'] === AITOCE_ACCOUNT_LEVELS[2])
        {
            if($custom_model['custom_llm'] === 1)
            {
                $message_body['own_llm'] = [
                    'aitoce_own_llm' => 1,
                    'aitoce_own_api_url' => $custom_model['custom_api_url'],
                    'aitoce_own_api_key' => $custom_model['custom_api_key'],
                    'aitoce_own_model' => $custom_model['custom_model'],
                ];
            }
            elseif(isset($openai_model['openai_api_key']) && !empty($openai_model['openai_api_key']))
            {
                $message_body['own_llm'] = [
                    'aitoce_own_llm' => 1,
                    'aitoce_own_api_url' => AITOCE_OPENAI_MODELS[$openai_model['openai_model']]['url'],
                    'aitoce_own_api_key' => $openai_model['openai_api_key'],
                    'aitoce_own_model' => $openai_model['openai_model'],
                ];
            }
        }




/*
        $body_settings['model'] = $this->options->aitoce_get_option(AITOCE_OPTION_NAME_MODEL_CUSTOM);

        // If using a custom LLM, add those settings to the request
        if ($body_settings['model']['custom_llm'] == 1) {
            $message_body['own_llm'] = [
                'aitoce_own_llm' => $body_settings['model']['custom_llm'],
                'aitoce_own_api_url' => $body_settings['model']['custom_api_url'],
                'aitoce_own_api_key' => $body_settings['model']['custom_api_key'],
                'aitoce_own_model' => $body_settings['model']['custom_model'],
            ];
        }*/

        // Prepare arguments for the API call
        $args = [
            'body' => wp_json_encode($message_body),
            'timeout' => 240,
        ];

        // Send the request to the backend API and get the response
        $atcapi_response_data = $this->api_call->aitoce_get_message($args);

        // Return the API response as a JSON success response
        wp_send_json_success([
            'success' => $atcapi_response_data['success'],
            'message' => $atcapi_response_data['message'],
            'assistant' => $atcapi_response_data['assistant'],
        ]);
    }

    /**
     * Send an error message as a JSON error response.
     *
     * @param string $aitoce_message The error message.
     * @param string $aitoce_code    The error code.
     */
    private function aitoce_send_error_message(string $aitoce_message, string $aitoce_code): void
    {
        wp_send_json_error([
            'message' => sprintf('%s - Code: %s', $aitoce_message, $aitoce_code),
            'assistant' => 'Assistant Offline!',
        ]);
    }

}
